@@ -4,15 +4,16 @@
 DailymotionUserPlaylistListModel::DailymotionUserPlaylistListModel(QObject *parent) :
     QAbstractListModel(parent)
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[PlaylistIdRole] = "playlistId";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[VideoCountRole] = "videoCount";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
+    m_roleNames[IdRole] = "id";
+    m_roleNames[PlaylistIdRole] = "playlistId";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[VideoCountRole] = "videoCount";
+    m_roleNames[DescriptionRole] = "description";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
 
     if (!Dailymotion::instance()->playlistsLoaded()) {
         Dailymotion::instance()->getPlaylists();
@@ -23,6 +24,12 @@ DailymotionUserPlaylistListModel::DailymotionUserPlaylistListModel(QObject *pare
     this->connect(Dailymotion::instance(), SIGNAL(playlistUpdated(int)), this, SLOT(onPlaylistUpdated(int)));
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> DailymotionUserPlaylistListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void DailymotionUserPlaylistListModel::onPlaylistAdded(int row) {
     this->beginInsertRows(QModelIndex(), row, row);
     this->endInsertRows();
