@@ -6,6 +6,9 @@
 #include "transfermanager.h"
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -78,9 +81,13 @@ void DailymotionVideoListModel::getVideos(QUrl feed) {
     else {
         feed = this->feed();
     }
-
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
+    feed.setQuery(query);
+#else
     feed.addQueryItem("fields", DAILYMOTION_VIDEO_FIELDS);
-
+#endif
     this->setLoading(true);
     QNetworkReply *reply = Dailymotion::instance()->createReply(feed, this->offset());
     reply->setParent(this);
