@@ -6,12 +6,19 @@ SelectionModel::SelectionModel(QObject *parent) :
     QStandardItemModel(parent),
     m_textAlignment(Qt::AlignCenter)
 {
-    QHash<int, QByteArray> roles;
-    roles[Qt::DisplayRole] = "name";
-    roles[Qt::UserRole + 1] = "value";
-    this->setRoleNames(roles);
+    m_roleNames[Qt::DisplayRole] = "name";
+    m_roleNames[Qt::UserRole + 1] = "value";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> SelectionModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 QString SelectionModel::name(int row) const {
     return this->data(this->index(row, 0), Qt::DisplayRole).toString();
 }
@@ -121,10 +128,17 @@ VideoServiceModel::VideoServiceModel(QObject *parent) :
 ScreenOrientationModel::ScreenOrientationModel(QObject *parent) :
     SelectionModel(parent)
 {
+#ifdef Q_WS_SAILFISH
+    this->addItem(tr("Automatic"), ScreenOrientation::Automatic);
+    this->addItem(tr("Portrait"), ScreenOrientation::LockPortrait);
+    this->addItem(tr("Portrait (inverted)"), ScreenOrientation::LockPortraitInverted);
+    this->addItem(tr("Landscape"), ScreenOrientation::LockLandscape);
+    this->addItem(tr("Landscape (inverted)"), ScreenOrientation::LockLandcapeInverted);
+#else
     this->addItem(tr("Automatic"), ScreenOrientation::Automatic);
     this->addItem(tr("Portrait"), ScreenOrientation::LockPortrait);
     this->addItem(tr("Landscape"), ScreenOrientation::LockLandscape);
-
+#endif
     emit countChanged(this->rowCount());
 }
 
@@ -429,7 +443,7 @@ MediaPlayerModel::MediaPlayerModel(QObject *parent) :
 {
 #ifdef CUTETUBE_PLAYER_ENABLED
     this->addItem(tr("cuteTube Player"), "cutetube");
-#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SYMBIAN_OS))
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (SYMBIAN_OS)) || (defined (Q_WS_SAILFISH))
     this->addItem(tr("cuteTube Player (simple)"), "cutetube_simple");
 #endif
 #endif
