@@ -12,13 +12,13 @@
 #include "transfermanager.h"
 #include "clipboardmonitor.h"
 #include "urlgrabber.h"
-#ifdef GRABBER_PLUGIN
-#include "../plugins/pluginmanager.h"
+#ifdef IN_APP_UPDATES
+#include "../updatemanager/updatemanager.h"
 #endif
 #ifndef QML_USER_INTERFACE
 #include "thumbnailcache.h"
 #ifdef Q_WS_MAEMO_5
-#include "windowstack.h"
+#include "../maemo5_gui/windowstack.h"
 #endif
 #endif
 #include <QNetworkAccessManager>
@@ -38,8 +38,8 @@ Session::Session(QObject *parent) :
     m_vimeo(new Vimeo(this)),
     m_sharing(new Sharing(this)),
     m_grabber(new UrlGrabber(this)),
-  #ifdef GRABBER_PLUGIN
-    m_pluginManager(new PluginManager(this)),
+  #ifdef IN_APP_UPDATES
+    m_updateManager(new UpdateManager(this)),
   #endif
     m_notifications(new Notifications(this)),
     m_transferManager(new TransferManager(this)),
@@ -118,12 +118,12 @@ Session::Session(QObject *parent) :
     this->connect(m_vimeo, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
     this->connect(m_sharing, SIGNAL(busy(QString,int)), m_notifications, SLOT(showProgressDialog(QString,int)));
     this->connect(m_sharing, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
-#ifdef GRABBER_PLUGIN
-    this->connect(m_pluginManager, SIGNAL(alert(QString)), m_notifications, SLOT(onAlert(QString)));
-    this->connect(m_pluginManager, SIGNAL(error(QString)), m_notifications, SLOT(onError(QString)));
-    this->connect(m_pluginManager, SIGNAL(info(QString)), m_notifications, SLOT(onInfo(QString)));
-    this->connect(m_pluginManager, SIGNAL(busy(QString,int)), m_notifications, SLOT(showProgressDialog(QString,int)));
-    this->connect(m_pluginManager, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
+#ifdef IN_APP_UPDATES
+    this->connect(m_updateManager, SIGNAL(alert(QString)), m_notifications, SLOT(onAlert(QString)));
+    this->connect(m_updateManager, SIGNAL(error(QString)), m_notifications, SLOT(onError(QString)));
+    this->connect(m_updateManager, SIGNAL(info(QString)), m_notifications, SLOT(onInfo(QString)));
+    this->connect(m_updateManager, SIGNAL(busy(QString,int)), m_notifications, SLOT(showProgressDialog(QString,int)));
+    this->connect(m_updateManager, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
 #endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_youtube, SIGNAL(alert(QString)), m_notifications, SLOT(cancelProgressDialog()));
@@ -142,11 +142,11 @@ Session::Session(QObject *parent) :
     this->connect(m_sharing, SIGNAL(error(QString)), m_notifications, SLOT(cancelProgressDialog()));
     this->connect(m_sharing, SIGNAL(info(QString)), m_notifications, SLOT(cancelProgressDialog()));
     this->connect(m_sharing, SIGNAL(currentOperationCancelled()), m_notifications, SLOT(cancelProgressDialog()));
-#ifdef GRABBER_PLUGIN
-    this->connect(m_pluginManager, SIGNAL(alert(QString)), m_notifications, SLOT(cancelProgressDialog()));
-    this->connect(m_pluginManager, SIGNAL(error(QString)), m_notifications, SLOT(cancelProgressDialog()));
-    this->connect(m_pluginManager, SIGNAL(info(QString)), m_notifications, SLOT(cancelProgressDialog()));
-    this->connect(m_pluginManager, SIGNAL(currentOperationCancelled()), m_notifications, SLOT(cancelProgressDialog()));
+#ifdef IN_APP_UPDATES
+    this->connect(m_updateManager, SIGNAL(alert(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(error(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(info(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(currentOperationCancelled()), m_notifications, SLOT(cancelProgressDialog()));
 #endif
 #endif
 
@@ -156,9 +156,8 @@ Session::Session(QObject *parent) :
     m_vimeo->setNetworkAccessManager(this->networkAccessManager());
     m_sharing->setNetworkAccessManager(this->networkAccessManager());
     m_transferManager->setNetworkAccessManager(this->networkAccessManager());
-#ifdef GRABBER_PLUGIN
-    m_pluginManager->setNetworkAccessManager(this->networkAccessManager());
-    m_pluginManager->loadPlugin();
+#ifdef IN_APP_UPDATES
+    m_updateManager->setNetworkAccessManager(this->networkAccessManager());
 #endif
     m_settings->restoreSettings();
     m_database->restoreAccounts();
