@@ -17,8 +17,8 @@ class Notifications;
 class TransferManager;
 class ClipboardMonitor;
 class QNetworkAccessManager;
-#ifdef GRABBER_PLUGIN
-class PluginManager;
+#ifdef IN_APP_UPDATES
+class UpdateManager;
 #endif
 #ifndef QML_USER_INTERFACE
 class ThumbnailCache;
@@ -52,8 +52,8 @@ private:
     Vimeo *m_vimeo;
     Sharing *m_sharing;
     UrlGrabber *m_grabber;
-#ifdef GRABBER_PLUGIN
-    PluginManager *m_pluginManager;
+#ifdef IN_APP_UPDATES
+    UpdateManager *m_updateManager;
 #endif
     Notifications *m_notifications;
     TransferManager *m_transferManager;
