@@ -1,11 +1,15 @@
 #include "settings.h"
 #include <QDir>
-#include <QDesktopServices>
 #include <QNetworkProxy>
 #include <QAuthenticator>
 #if (defined (SYMBIAN_OS)) && (defined (CUTETUBE_PLAYER_ENABLED))
 #include <QSystemDeviceInfo>
 #endif
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#else
+#include <QDesktopServices>
+#endif
 
 Settings* settingsInstance = 0;
 
@@ -53,8 +57,8 @@ Settings::Settings(QObject *parent) :
   #else
     m_cuteTubePlayerEnabled(false)
   #endif
-  #ifdef GRABBER_PLUGIN
-  ,m_updatePlugin(false)
+  #ifdef IN_APP_UPDATES
+  ,m_checkUpdate(false)
   #endif
 {
     if (!settingsInstance) {
@@ -113,8 +117,10 @@ void Settings::restoreSettings() {
     this->setDownloadPath(this->value("downloadPath", QString("/home/user/MyDocs/cuteTube/")).toString());
 #elif defined (SYMBIAN_OS)
     this->setDownloadPath(this->value("downloadPath", QString("E:/cuteTube/")).toString());
+#elif QT_VERSION >= 0x050000
+    this->setDownloadPath(this->value("downloadPath", QStandardPaths::writableLocation(QStandardPaths::MoviesLocation).append("/cuteTube/")).toString());
 #else
-    this->setDownloadPath(this->value("downloadPath", QDesktopServices::storageLocation(QDesktopServices::HomeLocation).append("/cuteTube/")).toString());
+    this->setDownloadPath(this->value("downloadPath", QDesktopServices::storageLocation(QDesktopServices::MoviesLocation).append("/cuteTube/")).toString());
 #endif
     this->endGroup();
 
@@ -153,7 +159,7 @@ void Settings::restoreSettings() {
 
     this->beginGroup("System");
     this->setLanguage(this->value("language", QString("en")).toString());
-    this->setScreenOrientation(static_cast<ScreenOrientation::Orientation>(this->value("screenOrientation", 0).toInt()));
+    this->setScreenOrientation(static_cast<ScreenOrientation::Orientation>(this->value("screenOrientation", ScreenOrientation::Orientation(ScreenOrientation::Automatic)).toInt()));
     this->setMonitorClipboard(this->value("monitorClipboard", false).toBool());
     this->setNetworkProxyType(static_cast<NetworkProxyType::ProxyType>(this->value("networkProxyType", NetworkProxyType::ProxyType(NetworkProxyType::HttpProxy)).toInt()));
     this->setNetworkProxyHostName(this->value("networkProxyHostName", QString()).toString());
@@ -161,8 +167,8 @@ void Settings::restoreSettings() {
     this->setNetworkProxyUser(this->value("networkProxyUser", QString()).toString());
     this->setNetworkProxyPassword(QString(QByteArray::fromBase64(this->value("networkProxyPassword", QByteArray()).toByteArray())));
     this->setNetworkProxy();
-#ifdef GRABBER_PLUGIN
-    this->setUpdatePluginOnStartup(this->value("updatePluginOnStartup", false).toBool());
+#ifdef IN_APP_UPDATES
+    this->setCheckForUpdateOnStartup(this->value("checkForUpdateOnStartup", false).toBool());
 #endif
     this->endGroup();
 }
@@ -234,8 +240,8 @@ void Settings::saveSettings() {
     this->setValue("networkProxyPort", this->networkProxyPort());
     this->setValue("networkProxyUser", this->networkProxyUser());
     this->setValue("networkProxyPassword", this->networkProxyPassword().toUtf8().toBase64());
-#ifdef GRABBER_PLUGIN
-    this->setValue("updatePluginOnStartup", this->updatePluginOnStartup());
+#ifdef IN_APP_UPDATES
+    this->setValue("checkForUpdateOnStartup", this->checkForUpdateOnStartup());
 #endif
     this->endGroup();
 }
@@ -845,11 +851,11 @@ void Settings::setCuteTubePlayerEnabled(bool enabled) {
     m_cuteTubePlayerEnabled = enabled;
 }
 
-#ifdef GRABBER_PLUGIN
-void Settings::setUpdatePluginOnStartup(bool update) {
-    if (update != this->updatePluginOnStartup()) {
-        m_updatePlugin = update;
-        emit updatePluginOnStartupChanged(update);
+#ifdef IN_APP_UPDATES
+void Settings::setCheckForUpdateOnStartup(bool check) {
+    if (check != this->checkForUpdateOnStartup()) {
+        m_checkUpdate = check;
+        emit checkForUpdateOnStartupChanged(check);
     }
 }
 #endif
