@@ -239,11 +239,11 @@ class Settings : public QSettings
     Q_PROPERTY(bool cuteTubePlayerEnabled
                READ cuteTubePlayerEnabled
                CONSTANT)
-#ifdef GRABBER_PLUGIN
-    Q_PROPERTY(bool updatePluginOnStartup
-               READ updatePluginOnStartup
-               WRITE setUpdatePluginOnStartup
-               NOTIFY updatePluginOnStartupChanged)
+#ifdef IN_APP_UPDATES
+    Q_PROPERTY(bool checkForUpdateOnStartup
+               READ checkForUpdateOnStartup
+               WRITE setCheckForUpdateOnStartup
+               NOTIFY checkForUpdateOnStartupChanged)
 #endif
 
 public:
@@ -316,8 +316,8 @@ public:
     bool eventFeedInstalled() const;
 #endif
     inline bool cuteTubePlayerEnabled() const { return m_cuteTubePlayerEnabled; }
-#ifdef GRABBER_PLUGIN
-    inline bool updatePluginOnStartup() const { return m_updatePlugin; }
+#ifdef IN_APP_UPDATES
+    inline bool checkForUpdateOnStartup() const { return m_checkUpdate; }
 #endif
 
     static Settings* instance();
@@ -386,8 +386,8 @@ public slots:
 #ifdef Q_WS_MAEMO_5
     void setEventFeedEnabled(bool enabled);
 #endif
-#ifdef GRABBER_PLUGIN
-    void setUpdatePluginOnStartup(bool update);
+#ifdef IN_APP_UPDATES
+    void setCheckForUpdateOnStartup(bool check);
 #endif
 
 private:
@@ -472,8 +472,8 @@ signals:
 #ifdef Q_WS_MAEMO_5
     void eventFeedEnabledChanged(bool enabled);
 #endif
-#ifdef GRABBER_PLUGIN
-    void updatePluginOnStartupChanged(bool update);
+#ifdef IN_APP_UPDATES
+    void checkForUpdateOnStartupChanged(bool check);
 #endif
 
 private:
@@ -526,8 +526,8 @@ private:
     bool m_eventFeedInstalled;
 #endif
     bool m_cuteTubePlayerEnabled;
-#ifdef GRABBER_PLUGIN
-    bool m_updatePlugin;
+#ifdef IN_APP_UPDATES
+    bool m_checkUpdate;
 #endif
 };
 
