@@ -5,7 +5,12 @@
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QNetworkReply>
+#if QT_VERSION >= 0x050000
+#include <QGuiApplication>
+#include <QUrlQuery>
+#else
 #include <QApplication>
+#endif
 #include <QClipboard>
 #include <QDateTime>
 #include <QDesktopServices>
@@ -58,16 +63,15 @@ void Sharing::clearCache() {
 void Sharing::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
-
-        if (isBusy) {
-            emit busy(message, numberOfOperations);
-        }
-        else {
-            emit busyProgressChanged(numberOfOperations);
-        }
-
         emit busyChanged(isBusy);
     }
+
+    if (isBusy) {
+        emit busy(message, numberOfOperations);
+    }
+    else {
+        emit busyProgressChanged(numberOfOperations);
+    }
 }
 
 void Sharing::cancelCurrentOperation() {
@@ -77,22 +81,38 @@ void Sharing::cancelCurrentOperation() {
 
 QUrl Sharing::facebookAuthUrl() const {
     QUrl url("https://www.facebook.com/dialog/oauth");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("client_id", FACEBOOK_CLIENT_ID);
+    query.addQueryItem("redirect_uri", "https://www.facebook.com/connect/login_success.html");
+    query.addQueryItem("response_type", "token");
+    query.addQueryItem("display", "touch");
+    query.addQueryItem("scope", "publish_stream,read_stream");
+    url.setQuery(query);
+#else
     url.addQueryItem("client_id", FACEBOOK_CLIENT_ID);
-    url.addQueryItem("redirect_uri", "http://www.facebook.com/connect/login_success.html");
+    url.addQueryItem("redirect_uri", "https://www.facebook.com/connect/login_success.html");
     url.addQueryItem("response_type", "token");
     url.addQueryItem("display", "touch");
     url.addQueryItem("scope", "publish_stream,read_stream");
-
+#endif
     return url;
 }
 
 void Sharing::signInToFacebook(const QUrl &response) {
-    QUrl url(response.toString().replace('#', '?'));
+    QUrl url(response.toString().replace('#', '?').replace("??", "?")); //Fix malformed response from Facebook
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    QString token = query.queryItemValue("access_token");
+#else
     QString token = url.queryItemValue("access_token");
-
+#endif
     if (token.isEmpty()) {
+#if QT_VERSION >= 0x050000
+        QString errorString = query.queryItemValue("error");
+#else
         QString errorString = url.queryItemValue("error");
-
+#endif
         if (errorString == "access_denied") {
             emit info(tr("You have denied access to your facebook account"));
         }
@@ -142,9 +162,14 @@ void Sharing::checkTwitterAuthUrl() {
     }
 
     QUrl url("http://twitter.com?" + reply->readAll());
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    QString token = query.queryItemValue("oauth_token");
+    QString secret = query.queryItemValue("oauth_token_secret");
+#else
     QString token = url.queryItemValue("oauth_token");
     QString secret = url.queryItemValue("oauth_token_secret");
-
+#endif
     if ((token.isEmpty()) || (secret.isEmpty())) {
         emit error(tr("Error obtaining twitter authorisation URL"));
     }
@@ -152,7 +177,13 @@ void Sharing::checkTwitterAuthUrl() {
         this->setTwitterRequestToken(token);
         this->setTwitterRequestSecret(secret);
         QUrl authUrl("http://api.twitter.com/oauth/authorize");
+#if QT_VERSION >= 0x050000
+        QUrlQuery query;
+        query.addQueryItem("oauth_token", token);
+        authUrl.setQuery(query);
+#else
         authUrl.addQueryItem("oauth_token", token);
+#endif
         emit gotTwitterAuthUrl(authUrl);
     }
 
@@ -160,8 +191,12 @@ void Sharing::checkTwitterAuthUrl() {
 }
 
 void Sharing::signInToTwitter(const QUrl &response) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(response);
+    QString verifier = query.queryItemValue("oauth_verifier");
+#else
     QString verifier = response.queryItemValue("oauth_verifier");
-
+#endif
     if (verifier.isEmpty()) {
         emit error(tr("Error obtaining twitter authorisation verifier"));
     }
@@ -190,9 +225,14 @@ void Sharing::checkIfSignedInToTwitter() {
     }
 
     QUrl url("http://twitter.com?" + reply->readAll());
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    QString token = query.queryItemValue("oauth_token");
+    QString secret = query.queryItemValue("oauth_token_secret");
+#else
     QString token = url.queryItemValue("oauth_token");
     QString secret = url.queryItemValue("oauth_token_secret");
-
+#endif
     if ((token.isEmpty()) || (secret.isEmpty())) {
         emit error(tr("Error obtaining twitter authorisation"));
     }
@@ -377,7 +417,11 @@ void Sharing::shareViaEmail(const QString &title, const QUrl &url) {
 void Sharing::copyToClipboard(const QUrl &url) {
     bool monitor = Settings::instance()->monitorClipboard();
     Settings::instance()->setMonitorClipboard(false);
+#if QT_VERSION >= 0x050000
+    QGuiApplication::clipboard()->setText(url.toString());
+#else
     QApplication::clipboard()->setText(url.toString());
+#endif
     emit alert(tr("Copied to clipboard"));
 
     if (monitor) {
@@ -405,13 +449,24 @@ void Sharing::getVideos(bool forceRefresh) {
 void Sharing::getVideosFromFacebook() {
     this->setBusy(true);
     QUrl url("https://graph.facebook.com/me/feed");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
 
+    if (this->facebookTimeStamp() > 0) {
+        query.addQueryItem("since", QString::number(this->facebookTimeStamp()));
+    }
+
+    query.addQueryItem("limit", "100");
+    query.addQueryItem("access_token", this->facebookToken());
+    url.setQuery(query);
+#else
     if (this->facebookTimeStamp() > 0) {
         url.addQueryItem("since", QString::number(this->facebookTimeStamp()));
     }
 
     url.addQueryItem("limit", "100");
     url.addQueryItem("access_token", this->facebookToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -492,6 +547,19 @@ void Sharing::checkFacebookVideos() {
 void Sharing::getVideosFromTwitter() {
     this->setBusy(true);
     QUrl url("http://api.twitter.com/1.1/statuses/home_timeline.json");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("count", "200");
+    query.addQueryItem("include_entities", "true");
+    query.addQueryItem("trim_user", "true");
+    query.addQueryItem("include_rts", "false");
+
+    if (!this->lastTweet().isEmpty()) {
+        query.addQueryItem("since_id", this->lastTweet());
+    }
+
+    url.setQuery(query);
+#else
     url.addQueryItem("count", "200");
     url.addQueryItem("include_entities", "true");
     url.addQueryItem("trim_user", "true");
@@ -500,7 +568,7 @@ void Sharing::getVideosFromTwitter() {
     if (!this->lastTweet().isEmpty()) {
         url.addQueryItem("since_id", this->lastTweet());
     }
-
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("Authorization", this->getTwitterOAuthHeader("GET", url, QMap<QString, QString>()));
