@@ -13,28 +13,30 @@ SocialVideoListModel::SocialVideoListModel(QObject *parent) :
     m_thumbnailPressedRow(-1)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[VideoIdRole] = "videoId";
-    roles[FavouriteIdRole] = "favouriteId";
-    roles[PlaylistVideoIdRole] = "playlistVideoId";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[DurationRole] = "duration";
-    roles[ViewCountRole] = "viewCount";
-    roles[RatingCountRole] = "ratingCount";
-    roles[RatingRole] = "rating";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[VideoIdRole] = "videoId";
+    m_roleNames[FavouriteIdRole] = "favouriteId";
+    m_roleNames[PlaylistVideoIdRole] = "playlistVideoId";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[DurationRole] = "duration";
+    m_roleNames[ViewCountRole] = "viewCount";
+    m_roleNames[RatingCountRole] = "ratingCount";
+    m_roleNames[RatingRole] = "rating";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
-    roles[ThumbnailPressedRole] = "thumbnailPressed";
+    m_roleNames[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailPressedRole] = "thumbnailPressed";
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[ArchiveRole] = "archive";
-    roles[ServiceRole] = "service";
-    roles[FavouriteRole] = "favourite";
-    roles[SelectedRole] = "selected";
-    this->setRoleNames(roles);
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[ArchiveRole] = "archive";
+    m_roleNames[ServiceRole] = "service";
+    m_roleNames[FavouriteRole] = "favourite";
+    m_roleNames[SelectedRole] = "selected";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -49,6 +51,12 @@ SocialVideoListModel::~SocialVideoListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> SocialVideoListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void SocialVideoListModel::onVideoAdded(int row) {
     this->beginInsertRows(QModelIndex(), row, row);
     this->endInsertRows();
