@@ -9,6 +9,9 @@
 #include <QRegExp>
 #include <QScriptEngine>
 #include <QDebug>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -144,17 +147,16 @@ void UrlGrabber::setVimeoFormats(QSet<int> formats) {
 void UrlGrabber::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
-
-        if (isBusy) {
-            this->setCancelled(false);
-            emit busy(message, numberOfOperations);
-        }
-        else if (!this->cancelled()) {
-            emit busyProgressChanged(numberOfOperations);
-        }
-
         emit busyChanged(isBusy);
     }
+
+    if (isBusy) {
+        this->setCancelled(false);
+        emit busy(message, numberOfOperations);
+    }
+    else if (!this->cancelled()) {
+        emit busyProgressChanged(numberOfOperations);
+    }
 }
 
 void UrlGrabber::cancelCurrentOperation() {
@@ -242,7 +244,21 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
                 params.removeDuplicates();
 
                 QUrl url(urlString.left(urlString.indexOf('?')));
+#if QT_VERSION >= 0x050000
+                QUrlQuery query;
 
+                foreach (QString param, params) {
+                    query.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
+                }
+
+                if (!query.hasQueryItem("signature")) {
+                    query.addQueryItem("signature", splitPart.first().section("signature=", 1, 1).section('&', 0, 0));
+                }
+
+                url.setQuery(query);
+
+                urlMap[query.queryItemValue("itag").toInt()] = url;
+#else
                 foreach (QString param, params) {
                     url.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
                 }
@@ -252,6 +268,7 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
                 }
 
                 urlMap[url.queryItemValue("itag").toInt()] = url;
+#endif
             }
         }
     }
@@ -267,7 +284,21 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
                 params.removeDuplicates();
 
                 QUrl url(urlString.left(urlString.indexOf('?')));
+#if QT_VERSION >= 0x050000
+                QUrlQuery query;
 
+                foreach (QString param, params) {
+                    query.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
+                }
+
+                if (!query.hasQueryItem("signature")) {
+                    query.addQueryItem("signature", splitPart.first().section("signature=", 1, 1).section('&', 0, 0));
+                }
+
+                url.setQuery(query);
+
+                urlMap[query.queryItemValue("itag").toInt()] = url;
+#else
                 foreach (QString param, params) {
                     url.addQueryItem(param.section('=', 0, 0), param.section('=', -1));
                 }
@@ -277,6 +308,7 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
                 }
 
                 urlMap[url.queryItemValue("itag").toInt()] = url;
+#endif
             }
         }
     }
@@ -291,12 +323,23 @@ void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
 
 void UrlGrabber::getYouTubeVideoInfoPage(const QString &id, const char *slot) {
     QUrl url("http://www.youtube.com/get_video_info");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("video_id", id);
+    query.addQueryItem("el", "detailpage");
+    query.addQueryItem("ps", "default");
+    query.addQueryItem("eurl", "gl");
+    query.addQueryItem("gl", "US");
+    query.addQueryItem("hl", "en");
+    url.setQuery(query);
+#else
     url.addQueryItem("video_id", id);
     url.addQueryItem("el", "detailpage");
     url.addQueryItem("ps", "default");
     url.addQueryItem("eurl", "gl");
     url.addQueryItem("gl", "US");
     url.addQueryItem("hl", "en");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -321,7 +364,11 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
 
     if (!response.contains("url_encoded_fmt_stream_map=")) {
         qDebug() << "No format map in YouTube video info page. Retrieving the web page";
+#if QT_VERSION >= 0x050000
+        this->getYouTubeVideoWebPage(QUrlQuery(reply->request().url()).queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+#else
         this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+#endif
     }
     else {
         response = response.section("url_encoded_fmt_stream_map=", 1, 1);
@@ -329,7 +376,11 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
 
         if ((separator == "s") || (response.contains("%26s%3D"))) {
             qDebug() << "YouTube video has encrypted signatures. Retrieving the web page";
+#if QT_VERSION >= 0x050000
+            this->getYouTubeVideoWebPage(QUrlQuery(reply->request().url()).queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+#else
             this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+#endif
         }
         else {
             qDebug() << "YouTube video info OK. Parsing the page";
@@ -343,10 +394,19 @@ void UrlGrabber::checkYouTubeVideoInfoPage() {
 
 void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     QUrl url("https://www.youtube.com/watch");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", id);
+    query.addQueryItem("gl", "US");
+    query.addQueryItem("hl", "en");
+    query.addQueryItem("has_verified", "1");
+    url.setQuery(query);
+#else
     url.addQueryItem("v", id);
     url.addQueryItem("gl", "US");
     url.addQueryItem("hl", "en");
     url.addQueryItem("has_verified", "1");
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -379,6 +439,11 @@ void UrlGrabber::checkYouTubeWebPage() {
     else {
         QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\": ", 1, 1).section('}', 0, 0))).toMap();
         QUrl playerUrl = assets.value("js").toUrl();
+
+	if (playerUrl.scheme().isEmpty()) {
+	    playerUrl.setScheme("http");
+	}
+
         response = response.section("url_encoded_fmt_stream_map\": \"", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
 
         bool encryptedSignatures = !response.contains("sig=");
@@ -569,7 +634,11 @@ void UrlGrabber::checkYouTubeVideoInfoFormats() {
 
     if (!response.contains("url_encoded_fmt_stream_map=")) {
         qDebug() << "No format map in YouTube video info page. Retrieving the web page";
+#if QT_VERSION >= 0x050000
+        this->getYouTubeVideoWebPage(QUrlQuery(reply->request().url()).queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+#else
         this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+#endif
     }
     else {
         response = response.section("url_encoded_fmt_stream_map=", 1, 1);
@@ -577,7 +646,11 @@ void UrlGrabber::checkYouTubeVideoInfoFormats() {
 
         if ((separator == "s") || (response.contains("%26s%3D"))) {
             qDebug() << "YouTube video has encrypted signatures. Retrieving the web page";
+#if QT_VERSION >= 0x050000
+            this->getYouTubeVideoWebPage(QUrlQuery(reply->request().url()).queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+#else
             this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+#endif
         }
         else {
             qDebug() << "YouTube video info OK. Parsing the page";
@@ -613,6 +686,11 @@ void UrlGrabber::checkYouTubeWebPageFormats() {
     else {
         QVariantMap assets = Json::parse(QString("%1}").arg(response.section("\"assets\": ", 1, 1).section('}', 0, 0))).toMap();
         QUrl playerUrl = assets.value("js").toUrl();
+
+	if (playerUrl.scheme().isEmpty()) {
+	    playerUrl.setScheme("http");
+	}
+
         response = response.section("url_encoded_fmt_stream_map\": \"", 1, 1).section(", \"", 0, 0).trimmed().replace("\\u0026", "&").remove(QRegExp("itag=\\d+"));
 
         bool encryptedSignatures = !response.contains("sig=");
