@@ -5,6 +5,9 @@
 #include "transfermanager.h"
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 VimeoVideoListModel::VimeoVideoListModel(QObject *parent) :
     AbstractVideoListModel(parent),
@@ -48,12 +51,23 @@ void VimeoVideoListModel::setFeed(const QUrl &feed) {
             this->connect(Vimeo::instance(), SIGNAL(addedToWatchLaterAlbum(QString)), this, SLOT(onAddedToWatchLaterAlbum(QString)));
             this->connect(Vimeo::instance(), SIGNAL(deletedFromWatchLaterAlbum(QString)), this, SLOT(onDeletedFromWatchLaterAlbum(QString)));
         }
+#if QT_VERSION >= 0x050000
+        else {
+            QUrlQuery query(feed);
+
+            if (query.queryItemValue("method") == "vimeo.albums.getVideos") {
+                this->setAlbumId(query.queryItemValue("album_id"));
+                this->connect(Vimeo::instance(), SIGNAL(addedToAlbum(QString,QString)), this, SLOT(onAddedToAlbum(QString,QString)));
+                this->connect(Vimeo::instance(), SIGNAL(deletedFromAlbum(QString,QString)), this, SLOT(onDeletedFromAlbum(QString,QString)));
+            }
+        }
+#else
         else if (feed.queryItemValue("method") == "vimeo.albums.getVideos") {
             this->setAlbumId(feed.queryItemValue("album_id"));
             this->connect(Vimeo::instance(), SIGNAL(addedToAlbum(QString,QString)), this, SLOT(onAddedToAlbum(QString,QString)));
             this->connect(Vimeo::instance(), SIGNAL(deletedFromAlbum(QString,QString)), this, SLOT(onDeletedFromAlbum(QString,QString)));
         }
-
+#endif
         emit feedChanged(feed);
     }
 }
@@ -82,20 +96,39 @@ void VimeoVideoListModel::getMoreVideos() {
 
 void VimeoVideoListModel::getGroupVideos(const QString &id) {
     QUrl feed(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("method", "vimeo.groups.getVideos");
+    query.addQueryItem("group_id", id);
+    query.addQueryItem("per_page", "30");
+    query.addQueryItem("full_response", "true");
+    query.addQueryItem("sort", "newest");
+    feed.setQuery(query);
+#else
     feed.addQueryItem("method", "vimeo.groups.getVideos");
     feed.addQueryItem("group_id", id);
     feed.addQueryItem("per_page", "30");
     feed.addQueryItem("full_response", "true");
     feed.addQueryItem("sort", "newest");
+#endif
     this->getVideos(feed);
 }
 
 void VimeoVideoListModel::getAlbumVideos(const QString &id) {
     QUrl feed(VIMEO_BASE_URL);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+    query.addQueryItem("method", "vimeo.albums.getVideos");
+    query.addQueryItem("album_id", id);
+    query.addQueryItem("per_page", "30");
+    query.addQueryItem("full_response", "true");
+    feed.setQuery(query);
+#else
     feed.addQueryItem("method", "vimeo.albums.getVideos");
     feed.addQueryItem("album_id", id);
     feed.addQueryItem("per_page", "30");
     feed.addQueryItem("full_response", "true");
+#endif
     this->getVideos(feed);
 }
 
