@@ -20,6 +20,9 @@ class VimeoVideoListModel : public AbstractVideoListModel
                READ feed
                WRITE setFeed
                NOTIFY feedChanged)
+    Q_PROPERTY(QString albumId
+               READ albumId
+               NOTIFY feedChanged)
     Q_PROPERTY(bool refreshRequired
                READ refreshRequired
                NOTIFY refreshRequiredChanged)
