@@ -10,8 +10,15 @@
 #include <QDebug>
 #include <QTimer>
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+#include <QQmlEngine>
+#else
 #include <QDeclarativeEngine>
 #endif
+#endif
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -63,17 +70,16 @@ YouTube* YouTube::instance() {
 void YouTube::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
     if (isBusy != this->busy()) {
         m_busy = isBusy;
-
-        if (isBusy) {
-            this->setCancelled(false);
-            emit busy(message, numberOfOperations);
-        }
-        else if (!this->cancelled()) {
-            emit busyProgressChanged(numberOfOperations);
-        }
-
         emit busyChanged(isBusy);
     }
+
+    if (isBusy) {
+        this->setCancelled(false);
+        emit busy(message, numberOfOperations);
+    }
+    else if (!this->cancelled()) {
+        emit busyProgressChanged(numberOfOperations);
+    }
 }
 
 void YouTube::cancelCurrentOperation() {
@@ -91,6 +97,19 @@ void YouTube::cancelCurrentOperation() {
 }
 
 QNetworkReply* YouTube::createReply(QUrl feed, int offset) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(feed);
+
+    if (this->userSignedIn()) {
+        query.addQueryItem("access_token", this->accessToken());
+    }
+
+    if (offset) {
+        query.addQueryItem("start-index", QString::number(offset));
+    }
+
+    feed.setQuery(query);
+#else
     if (this->userSignedIn()) {
         feed.addQueryItem("access_token", this->accessToken());
     }
@@ -98,7 +117,7 @@ QNetworkReply* YouTube::createReply(QUrl feed, int offset) {
     if (offset) {
         feed.addQueryItem("start-index", QString::number(offset));
     }
-
+#endif
     qDebug() << feed;
 
     QNetworkRequest request(feed);
@@ -110,7 +129,49 @@ QNetworkReply* YouTube::createReply(QUrl feed, int offset) {
 
 QNetworkReply* YouTube::createSearchReply(int queryType, const QString &query, int offset, int order, int time, int duration, const QString &language) {
     QUrl url;
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery;
 
+    switch (queryType) {
+    case Queries::Videos:
+        url.setUrl(YOUTUBE_VIDEOS_BASE_URL);
+        urlQuery.addQueryItem("fields", YOUTUBE_VIDEO_FIELDS);
+        urlQuery.addQueryItem("orderby", m_queryOrders.value(order, "relevance"));
+        urlQuery.addQueryItem("time", m_timeFilters.value(time, "all_time"));
+
+        if (duration != Queries::Any) {
+            urlQuery.addQueryItem("duration", m_durationFilters.value(duration, "medium"));
+        }
+        if ((!language.isEmpty()) && (language != "all")) {
+            urlQuery.addQueryItem("lr", language);
+        }
+        break;
+    case Queries::Playlists:
+        url.setUrl(YOUTUBE_PLAYLISTS_SEARCH_BASE_URL);
+        urlQuery.addQueryItem("fields", YOUTUBE_PLAYLIST_FIELDS);
+        urlQuery.addQueryItem("orderby", "relevance");
+        break;
+    case Queries::Users:
+        url.setUrl(YOUTUBE_CHANNELS_BASE_URL);
+        urlQuery.addQueryItem("fields", YOUTUBE_USER_FIELDS);
+        urlQuery.addQueryItem("orderby", "relevance");
+        break;
+    default:
+        qWarning() << "YouTube::createSearchReply(): No/invalid query type.";
+        break;
+    }
+
+    urlQuery.addQueryItem("q", QString("\"%1\"|%2").arg(query).arg(query.simplified().replace(' ', '+')));
+    urlQuery.addQueryItem("v", "2.1");
+    urlQuery.addQueryItem("safeSearch", this->safeSearch() ? "strict" : "none");
+    urlQuery.addQueryItem("max-results", "30");
+
+    if (offset) {
+        urlQuery.addQueryItem("start-index", QString::number(offset));
+    }
+
+    url.setQuery(urlQuery);
+#else
     switch (queryType) {
     case Queries::Videos:
         url.setUrl(YOUTUBE_VIDEOS_BASE_URL);
@@ -148,7 +209,7 @@ QNetworkReply* YouTube::createSearchReply(int queryType, const QString &query, i
     if (offset) {
         url.addQueryItem("start-index", QString::number(offset));
     }
-
+#endif
     qDebug() << url;
 
     QNetworkRequest request(url);
@@ -189,13 +250,23 @@ QNetworkReply* YouTube::createUploadReply(const QVariantMap &metadata) {
 
 QUrl YouTube::authUrl() const {
     QUrl url("https://accounts.google.com/o/oauth2/auth");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("client_id", CLIENT_ID);
+    query.addQueryItem("redirect_uri", "urn:ietf:wg:oauth:2.0:oob");
+    query.addQueryItem("response_type", "code");
+    query.addQueryItem("scope", "https://gdata.youtube.com");
+    query.addQueryItem("access_type", "offline");
+    query.addQueryItem("display", "popup");
+    url.setQuery(query);
+#else
     url.addQueryItem("client_id", CLIENT_ID);
     url.addQueryItem("redirect_uri", "urn:ietf:wg:oauth:2.0:oob");
     url.addQueryItem("response_type", "code");
     url.addQueryItem("scope", "https://gdata.youtube.com");
     url.addQueryItem("access_type", "offline");
     url.addQueryItem("display", "popup");
-
+#endif
     return url;
 }
 
@@ -384,7 +455,13 @@ void YouTube::checkDeviceToken() {
 void YouTube::signOut() {
     this->setBusy(true, tr("Signing out"));
     QUrl url("https://accounts.google.com/o/oauth2/revoke");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
     this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedOut()));
@@ -497,9 +574,17 @@ void YouTube::onGoogleAccountLinked(const QString &response) {
 
 void YouTube::checkUsernameAvailability(QString username) {
     QUrl url("https://gdata.youtube.com/feeds/api/suggest/username");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", "entry/title");
+    query.addQueryItem("hint", username);
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", "entry/title");
     url.addQueryItem("hint", username);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     request.setRawHeader("X-Gdata-Key", "key=" + DEVELOPER_KEY);
@@ -527,12 +612,19 @@ void YouTube::checkSuggestedUsernames() {
     if (usernames.isEmpty()) {
         emit usernameUnavailable();
     }
-    else if (usernames.contains(reply->request().url().queryItemValue("hint"))) {
-        emit usernameAvailable();
-        this->linkGoogleAccount(reply->request().url().queryItemValue("hint"));
-    }
     else {
-        emit gotSuggestedUsernames(usernames);
+#if QT_VERSION >= 0x050000
+        QString hint = QUrlQuery(reply->request().url()).queryItemValue("hint");
+#else
+        QString hint = reply->request().url().queryItemValue("hint");
+#endif
+        if (usernames.contains(hint)) {
+            emit usernameAvailable();
+            this->linkGoogleAccount(hint);
+        }
+        else {
+            emit gotSuggestedUsernames(usernames);
+        }
     }
 
     reply->deleteLater();
@@ -660,9 +752,17 @@ void YouTube::postFinished() {
 void YouTube::getPlaylists(int offset) {
     this->setPlaylistsLoaded(false);
     QUrl url(YOUTUBE_PLAYLISTS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("start-index", QString::number(offset));
+    query.addQueryItem("fields", YOUTUBE_PLAYLIST_FIELDS);
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("start-index", QString::number(offset));
     url.addQueryItem("fields", YOUTUBE_PLAYLIST_FIELDS);
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -766,9 +866,17 @@ void YouTube::updatePlaylistThumbnail(const QString &id, const QUrl &thumbnailUr
 void YouTube::getSubscriptions(int offset) {
     this->setSubscriptionsLoaded(false);
     QUrl url(YOUTUBE_SUBSCRIPTIONS_FEED);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+    query.addQueryItem("start-index", QString::number(offset));
+    query.addQueryItem("fields", YOUTUBE_SUBSCRIPTION_FIELDS);
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("start-index", QString::number(offset));
     url.addQueryItem("fields", YOUTUBE_SUBSCRIPTION_FIELDS);
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -870,8 +978,15 @@ void YouTube::getFullVideo(QString id) {
     }
 
     QUrl url(YOUTUBE_VIDEOS_BASE_URL + QString("/") + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_SINGLE_VIDEO_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_SINGLE_VIDEO_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -900,7 +1015,11 @@ void YouTube::checkFullVideo() {
         VideoItem *video = new VideoItem;
         video->loadYouTubeVideo(doc.namedItem("entry"));
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(video, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(video, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotVideo(video);
 #else
         emit gotVideo(QSharedPointer<VideoItem>(video));
@@ -920,8 +1039,15 @@ void YouTube::checkFullVideo() {
 
 void YouTube::getVideoMetadata(const QString &id) {
     QUrl url(YOUTUBE_VIDEOS_BASE_URL + QString("/") + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -991,8 +1117,15 @@ void YouTube::checkVideoMetadata() {
 
 void YouTube::getFullComment(const QString &videoId, const QString &commentId) {
     QUrl url(YOUTUBE_VIDEOS_BASE_URL + QString("/%1/comments/%2").arg(videoId).arg(commentId));
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1025,9 +1158,17 @@ void YouTube::checkFullComment() {
 
 void YouTube::getCurrentUserProfile() {
     QUrl url("https://gdata.youtube.com/feeds/api/users/default");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_USER_PROFILE_FIELDS);
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_USER_PROFILE_FIELDS);
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1060,7 +1201,11 @@ void YouTube::checkCurrentUserProfile() {
         }
 
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotUser(user);
 #else
         emit gotUser(QSharedPointer<UserItem>(user));
@@ -1074,8 +1219,15 @@ void YouTube::checkCurrentUserProfile() {
 
 void YouTube::getUserProfile(const QString &id) {
     QUrl url(YOUTUBE_USERS_BASE_URL + QString("/") + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_USER_PROFILE_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_USER_PROFILE_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1107,7 +1259,11 @@ void YouTube::checkUserProfile() {
             this->connect(this, SIGNAL(allSubscriptionsLoaded()), this, SLOT(subscribedToChannel()));
         }
 #ifdef QML_USER_INTERFACE
-        QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+            QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
+            QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotUser(user);
 #else
         emit gotUser(QSharedPointer<UserItem>(user));
@@ -1571,9 +1727,17 @@ void YouTube::onPlaylistCreated(const QString &response) {
 
 void YouTube::getPlaylistForCache(const QString &id) {
     QUrl url("https://gdata.youtube.com/feeds/api/users/default/playlists/" + id);
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_SINGLE_PLAYLIST_FIELDS);
+    query.addQueryItem("access_token", this->accessToken());
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_SINGLE_PLAYLIST_FIELDS);
     url.addQueryItem("access_token", this->accessToken());
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("X-Gdata-Key", "key=" + DEVELOPER_KEY);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
@@ -1823,8 +1987,15 @@ void YouTube::onCommentAdded(const QString &response) {
 
 void YouTube::getAddedComment(const QString &videoId, const QString &commentId) {
     QUrl url(QString("%1/%2/comments/%3").arg(QString(YOUTUBE_VIDEOS_BASE_URL)).arg(videoId).arg(commentId));
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("v", "2.1");
+    query.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
+    url.setQuery(query);
+#else
     url.addQueryItem("v", "2.1");
     url.addQueryItem("fields", YOUTUBE_SINGLE_COMMENT_FIELDS);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -1887,8 +2058,7 @@ void YouTube::onCommentActionError(const QString &errorString) {
 
 void YouTube::getVideosFromIds(QStringList ids) {
     this->setBusy(true, QString(), 0);
-    QUrl url("https://gdata.youtube.com/feeds/api/videos/batch");
-    url.addQueryItem("v", "2.1");
+    QUrl url("https://gdata.youtube.com/feeds/api/videos/batch?v=2.1");
 
     QByteArray xml("<feed xmlns=\"http://www.w3.org/2005/Atom\" xmlns:media=\"http://search.yahoo.com/mrss/\"\n" \
                    "xmlns:batch=\"http://schemas.google.com/gdata/batch\" xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n"
