@@ -102,6 +102,8 @@ public:
 
 public slots:
     void signIn(const QString &displayName, const QString &code);
+    void signInFromDevice(const QString &displayName);
+    void signOut();
     void getPlaylists(int offset = 1);
     void getSubscriptions(int offset = 1);
     inline void setSafeSearch(bool safe) { m_safeSearch = safe; }
@@ -137,6 +139,7 @@ public slots:
     void cancelCurrentOperation();
 
 private:
+    void clearLoginInfo();
     inline QString accessToken() const { return m_token; }
     inline void setAccessToken(const QString &token) { m_token = token; emit userSignedInChanged(); }
     inline QString refreshToken() const { return m_refreshToken; }
@@ -160,7 +163,11 @@ private slots:
     void putRequest(const QUrl &url, const QByteArray &xml);
     void deleteRequest(const QUrl &url);
     void postFinished();
+    void checkDeviceSignInInfo();
+    void pollServerForDeviceToken();
+    void checkDeviceToken();
     void checkIfSignedIn();
+    void checkIfSignedOut();
     void checkTokenRefresh();
     void deleteFromUploads();
     void onVideoDeleted();
@@ -261,6 +268,13 @@ signals:
 
 private:
     QNetworkAccessManager *m_nam;
+
+    struct Login {
+        QString displayName;
+        QString deviceCode;
+        int deviceInterval;
+    } m_login;
+
     QString m_user;
     QString m_token;
     QString m_refreshToken;
