@@ -10,21 +10,23 @@ YouTubeSubscriptionListModel::YouTubeSubscriptionListModel(QObject *parent) :
     ,m_cache(new ThumbnailCache)
   #endif
 {
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[SubscriptionIdRole] = "subscriptionId";
-    roles[UsernameRole] = "username";
-    roles[ChannelNameRole] = "channelName";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[SubscriptionIdRole] = "subscriptionId";
+    m_roleNames[UsernameRole] = "username";
+    m_roleNames[ChannelNameRole] = "channelName";
 #ifndef QML_USER_INTERFACE
-    roles[AvatarRole] = "avatar";
+    m_roleNames[AvatarRole] = "avatar";
 #endif
-    roles[AvatarUrlRole] = "avatarUrl";
-    roles[VideoCountRole] = "videoCount";
-    roles[DescriptionRole] = "description";
-    roles[ViewCountRole] = "viewCount";
-    roles[SubscriberCountRole] = "subscriberCount";
-    roles[SubscriptionRole] = "subscription";
-    this->setRoleNames(roles);
+    m_roleNames[AvatarUrlRole] = "avatarUrl";
+    m_roleNames[VideoCountRole] = "videoCount";
+    m_roleNames[DescriptionRole] = "description";
+    m_roleNames[ViewCountRole] = "viewCount";
+    m_roleNames[SubscriberCountRole] = "subscriberCount";
+    m_roleNames[SubscriptionRole] = "subscription";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
+#endif
+
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
 #endif
@@ -43,6 +45,12 @@ YouTubeSubscriptionListModel::~YouTubeSubscriptionListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> YouTubeSubscriptionListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void YouTubeSubscriptionListModel::onSubscriptionAdded(int row) {
     this->beginInsertRows(QModelIndex(), row, row);
     this->endInsertRows();
