@@ -72,6 +72,6 @@ void AboutDialog::donate() {
 }
 
 void AboutDialog::reportBug() {
-    QDesktopServices::openUrl(QUrl("mailto:stuhowarth77@gmail.com?subject=cuteTube for N900"));
+    QDesktopServices::openUrl(QUrl(QString("mailto:showarth@marxoft.co.uk?subject=cuteTube %1 for N900").arg(Utils::versionNumberString())));
     this->close();
 }
