@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/videoitem.h"
 
-class Session;
 class DailymotionCommentListModel;
 class ListView;
 class QAction;
@@ -17,7 +16,7 @@ class DailymotionVideoCommentsTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit DailymotionVideoCommentsTab(Session *session, QSharedPointer<VideoItem> video, QWidget *parent);
+    explicit DailymotionVideoCommentsTab(QSharedPointer<VideoItem> video, QWidget *parent);
 
 private:
     void setLandscapeLayout();
@@ -30,7 +29,6 @@ private slots:
     void showUserChannel(const QModelIndex &index);
 
 private:
-    Session *m_session;
     QSharedPointer<VideoItem> m_video;
     DailymotionCommentListModel *m_model;
     ListView *m_listView;
