@@ -35,7 +35,7 @@
 #include "../base/youtube.h"
 #include "../base/dailymotion.h"
 #include "../base/vimeo.h"
-#include "../base/windowstack.h"
+#include "windowstack.h"
 #include "../base/settings.h"
 #include "../base/clipboardmonitor.h"
 #include <QGridLayout>
