@@ -3,17 +3,17 @@
 
 #include "abstractdialog.h"
 
-class Settings;
 class QCheckBox;
 class QGridLayout;
 class QDialogButtonBox;
 class QScrollArea;
 
-class PlaybackQualityDialog : public AbstractDialog
+class PlaybackFormatDialog : public AbstractDialog
 {
     Q_OBJECT
+
 public:
-    explicit PlaybackQualityDialog(Settings *settings, QWidget *parent = 0);
+    explicit PlaybackFormatDialog(QWidget *parent = 0);
 
 private slots:
     void saveSettings();
@@ -24,7 +24,6 @@ private:
     void setPortraitLayout();
     
 private:
-    Settings *m_settings;
     QCheckBox *m_youtube720Checkbox;
     QCheckBox *m_youtube480Checkbox;
     QCheckBox *m_youtube360Checkbox;
