@@ -4,7 +4,6 @@
 #include "stackedwindow.h"
 #include "../base/videoitem.h"
 
-class Session;
 class ListView;
 class QModelIndex;
 class QAction;
@@ -13,8 +12,9 @@ class QLabel;
 class PlaybackQueueWindow : public StackedWindow
 {
     Q_OBJECT
+
 public:
-    explicit PlaybackQueueWindow(Session *session, QWidget *parent = 0);
+    explicit PlaybackQueueWindow(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
