@@ -1,6 +1,6 @@
 #include "stackedwindow.h"
 #include "../base/settings.h"
-#include "../base/windowstack.h"
+#include "windowstack.h"
 #include <QApplication>
 #include <QDesktopWidget>
 
