@@ -4,15 +4,12 @@
 #include "../base/enums.h"
 #include <QMainWindow>
 
-class Session;
-
 class StackedWindow : public QMainWindow
 {
     Q_OBJECT
 
 public:
     explicit StackedWindow(QWidget *parent = 0);
-    explicit StackedWindow(Session *session, QWidget *parent);
     ~StackedWindow() {}
     inline bool inPortrait() const { return m_portrait; }
 
@@ -25,9 +22,6 @@ protected:
     inline virtual void setLandscapeLayout() {}
     inline virtual void setPortraitLayout() {}
 
-protected:
-    Session *m_session;
-
 private:
     bool m_portrait;
 };
