@@ -2,7 +2,7 @@
 #define TRANSFERDETAILSDIALOG_H
 
 #include "abstractdialog.h"
-#include "../base/transferitem.h"
+#include "transferitem.h"
 
 class TransferPrioritySelector;
 class QLabel;
