@@ -7,7 +7,6 @@
 #include <QNetworkReply>
 #include <QDir>
 #include <QRegExp>
-#include <QPixmap>
 #include <QDebug>
 
 const QRegExp illegalChars("[\"@&~=\\/:?#!|<>*^]");
@@ -344,6 +343,9 @@ void TransferItem::cancelTransfer() {
     if (m_reply) {
         m_reply->abort();
     }
+    else if (!m_file.fileName().isEmpty()) {
+        m_file.remove();
+    }
 }
 
 void TransferItem::onDownloadMetadataChanged() {
