@@ -1,6 +1,6 @@
 #include "transfermovedialog.h"
 #include "transfermovedelegate.h"
-#include "../base/transferlistmodel.h"
+#include "transferlistmodel.h"
 #include <QListView>
 #include <QGridLayout>
 
