@@ -19,14 +19,24 @@
 #include <QDir>
 #include <QDateTime>
 #include <QSettings>
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
 #include <QNetworkConfigurationManager>
 #include <QNetworkSession>
+#ifdef MEEGO_EDITION_HARMATTAN
 #include <meegotouchevents/meventfeed.h>
+#else
+#include <meegotouchevents-qt5/meventfeed.h>
+#endif
 #endif
 #ifdef Q_WS_MAEMO_5
 #include "alarm.h"
 #endif
+#if QT_VERSION >= 0x050000
+const QString HOME_DIR(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+#else
+#include <QDesktopServices>
+const QString HOME_DIR(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
+#endif
 
 using namespace QtJson;
 
@@ -71,7 +81,7 @@ void Events::init() {
 
 bool Events::enableSync() {
     QSettings settings("cuteTube", "cuteTube");
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     settings.setValue("Events/eventFeedEnabled", true);
     bool success = true;
 #else
@@ -94,7 +104,7 @@ bool Events::enableSync() {
 
 bool Events::disableSync() {
     QSettings settings("cuteTube", "cuteTube");
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     settings.remove("Events/youtubeLatest");
     settings.remove("Events/dailymotionLatest");
     settings.remove("Events/vimeoLatest");
@@ -187,6 +197,7 @@ void Events::processYouTubeEvents() {
             QDomElement mediaGroup = entry.firstChildElement("media:group");
             Event event;
             event.setId(mediaGroup.firstChildElement("yt:videoid").text());
+            event.setUrl("http://youtu.be/" + event.id());
             event.setSourceName("cutetube");
             event.setSourceDisplayName("cuteTube");
             event.setIconPath("/usr/share/icons/hicolor/64x64/apps/cutetube64.png");
@@ -196,7 +207,9 @@ void Events::processYouTubeEvents() {
             event.setFooter(mediaGroup.firstChildElement("media:credit").attribute("yt:display"));
 #ifdef MEEGO_EDITION_HARMATTAN
             event.setTimestamp(QDateTime::fromString(mediaGroup.firstChildElement("yt:uploaded").text(), Qt::ISODate).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-            event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant("http://youtu.be/" + event.id()))));
+            event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
+#elif defined (Q_WS_SAILFISH)
+            event.setTimestamp(QDateTime::fromString(mediaGroup.firstChildElement("yt:uploaded").text(), Qt::ISODate).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
             event.setTimestamp(mediaGroup.firstChildElement("yt:uploaded").text());
             event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://youtu.be/" + event.id());
@@ -212,7 +225,7 @@ void Events::processYouTubeEvents() {
             this->getDailymotionEvents();
         }
         else {
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
             this->downloadThumbnails();
 #else
             this->addEvents();
@@ -261,6 +274,7 @@ void Events::processDailymotionEvents() {
             if (date > dailymotionLatest) {
                 Event event;
                 event.setId(entry.value("id").toString());
+                event.setUrl("http://dai.ly/" + event.id());
                 event.setSourceName("cutetube");
                 event.setSourceDisplayName("cuteTube");
                 event.setIconPath("/usr/share/icons/hicolor/64x64/apps/cutetube64.png");
@@ -270,7 +284,9 @@ void Events::processDailymotionEvents() {
                 event.setFooter(entry.value("owner.username").toString());
 #ifdef MEEGO_EDITION_HARMATTAN
                 event.setTimestamp(QDateTime::fromMSecsSinceEpoch(date).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant("http://dai.ly/" + event.id()))));
+                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
+#elif defined (Q_WS_SAILFISH)
+                event.setTimestamp(QDateTime::fromMSecsSinceEpoch(date).toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
                 event.setTimestamp(QString::number(date));
                 event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://dai.ly/" + event.id());
@@ -287,7 +303,7 @@ void Events::processDailymotionEvents() {
             this->getVimeoEvents();
         }
         else {
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
             this->downloadThumbnails();
 #else
             this->addEvents();
@@ -326,6 +342,7 @@ void Events::processVimeoEvents() {
             if (date > vimeoLatest) {
                 Event event;
                 event.setId(entry.attribute("id"));
+                event.setUrl("http://vimeo.com/" + event.id());
                 event.setSourceName("cutetube");
                 event.setSourceDisplayName("cuteTube");
                 event.setIconPath("/usr/share/icons/hicolor/64x64/apps/cutetube64.png");
@@ -341,7 +358,9 @@ void Events::processVimeoEvents() {
 
 #ifdef MEEGO_EDITION_HARMATTAN
                 event.setTimestamp(date.toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
-                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant("http://vimeo.com/" + event.id()))));
+                event.setAction(QString("com.maemo.cuteTube / com.maemo.cuteTube display %1").arg(this->base64SerializedVariant(QVariant(event.url()))));
+#elif defined (Q_WS_SAILFISH)
+                event.setTimestamp(date.toLocalTime().toString("yyyy-MM-dd hh:mm:ss"));
 #else
                 event.setTimestamp(QString::number(date.toMSecsSinceEpoch()));
                 event.setAction("dbus:session com.maemo.cuteTube / com.maemo.cuteTube display http://vimeo.com/" + event.id());
@@ -353,7 +372,7 @@ void Events::processVimeoEvents() {
         if (!entries.isEmpty()) {
             QSettings("cuteTube", "cuteTube").setValue("Events/vimeoLatest", QDateTime::currentMSecsSinceEpoch());
         }
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
         this->downloadThumbnails();
 #else
         this->addEvents();
@@ -367,12 +386,13 @@ void Events::processVimeoEvents() {
 }
 
 void Events::addEvents() {
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     while (!m_events.isEmpty()) {
         QVariantList args;
         QVariantMap itemArgs;
         Event event = m_events.takeFirst();
         itemArgs.insert("title", event.title());
+        itemArgs.insert("url", event.url());
         itemArgs.insert("icon", event.iconPath());
         itemArgs.insert("body", event.body());
         itemArgs.insert("imageList", QStringList(event.imagePathOne()));
@@ -384,7 +404,11 @@ void Events::addEvents() {
         itemArgs.insert("action", event.action());
         args.append(itemArgs);
 
+#ifdef MEEGO_EDITION_HARMATTAN
         QDBusInterface("com.nokia.home.EventFeed", "/eventfeed", "com.nokia.home.EventFeed").callWithArgumentList(QDBus::Block, "addItem", args);
+#else
+        QDBusInterface("org.nemomobile.events.EventFeed", "/org/nemomobile/events/EventFeed", "org.nemomobile.events.EventFeed").callWithArgumentList(QDBus::Block, "addItem", args);
+#endif
     }
 #else
     while (!m_events.isEmpty()) {
@@ -406,7 +430,7 @@ void Events::addEvents() {
     this->syncSuccess();
 }
 
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
 QString Events::base64SerializedVariant(const QVariant &value) const
 {
     QByteArray ba;
@@ -417,7 +441,7 @@ QString Events::base64SerializedVariant(const QVariant &value) const
 
 void Events::downloadThumbnails() {
     if ((m_index >= 0) && (m_index < m_events.size())) {
-        QFileInfo info(QString("/home/user/cuteTube/.feedthumbnails/%1.jpg").arg(m_events[m_index].id()));
+        QFileInfo info(QString("%1/cuteTube/.feedthumbnails/%1.jpg").arg(HOME_DIR).arg(m_events[m_index].id()));
 
         if (info.exists()) {
             m_events[m_index].setImagePathOne(info.absoluteFilePath());
@@ -444,9 +468,9 @@ void Events::onThumbnailDownloaded() {
         return;
     }
 
-    QDir dir("/home/user/cuteTube/.feedthumbnails/");
+    QDir dir(HOME_DIR + "/cuteTube/.feedthumbnails/");
     dir.mkpath(dir.path());
-    QFile file(QString("/home/user/cuteTube/.feedthumbnails/%1.jpg").arg(m_events[m_index].id()));
+    QFile file(QString("%1/cuteTube/.feedthumbnails/%2.jpg").arg(HOME_DIR).arg(m_events[m_index].id()));
 
     if (file.open(QIODevice::WriteOnly)) {
         file.write(reply->readAll());
@@ -460,7 +484,7 @@ void Events::onThumbnailDownloaded() {
 }
 
 void Events::clearThumbnails() {
-    QDir dir("/home/user/cuteTube/.feedthumbnails/");
+    QDir dir(HOME_DIR + "/cuteTube/.feedthumbnails/");
 
     foreach (QString thumbnail, dir.entryList(QStringList("*.jpg"))) {
         dir.remove(thumbnail);
