@@ -37,14 +37,14 @@ private slots:
     void processDailymotionEvents();
     void getVimeoEvents();
     void processVimeoEvents();
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     void onThumbnailDownloaded();
 #endif
 
 private:
     void init();
     void addEvents();
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     QString base64SerializedVariant(const QVariant &value) const;
     void downloadThumbnails();
     void clearThumbnails();
